"use strict";

module.exports = {
  env: {
    webextensions: true,
  },

  rules: {
    "no-shadow": "off",
  },
};
